
#ifndef PILES_H
#define PILES_H

/**
 * Classe d'objet representant une structure de
 * pile.  Des pointeurs sur les objets a empiler
 * sont utilises comme elements.  L'allocation et
 * la liberation des elements est la responsabilite 
 * del'utilisateur. 
 */
typedef struct _pile Pile;

/**
 * constructeur de pile.
 * @return une pile vide. 
 */
Pile * creerPile( void );


/** 
 * fonction retournant le nombre d'elements dans 
 * la pile.
 * @param a_pile Pile * la pile a consulter.
 * @pre a_pile != NULL
 * @return le nombre d'element que contient la pile.
 * @post retour >= 0
 */
int taillePile( Pile * a_pile );


/**
 * fonctiont retournant vrai si la pile est vide.
 * @param a_pile Pile * la pile a consulter.
 * @pre a_pile != NULL
 * @return vrai si la pile est vide, faux sinon.
 */	
int estVidePile( Pile * a_pile );


/**
 * Procedure empilant un element au sommet de la pile.
 * @param a_pile Pile * la pile a consulter.
 * @pre a_pile != NULL
 * @param a_element voit * l'element empiler. 
 */
void empilerPile( Pile * a_pile, void * a_element );


/**
 * Retourne l'element au sommet de la pile.
 * @param a_pile Pile * la pile a consulter.
 * @pre a_pile != NULL
 * @pre ! estVidePile( a_pile )
 * @return l'element au sommet de la pile.
 */
void * sommetPile( Pile * a_pile );


/**
 * Procedure qui depile le sommet de la pile.
 * @param a_pile Pile * la pile a consulter.
 * @pre a_pile != NULL
 * @pre ! estVidePile( a_pile )
 */
void depilerPile( Pile * a_pile );


#endif
